% FUNCTION: FT_plot(test, sampling frequency, cutoff, butterworth order)
% This function takes your seven column array of force and torque data, and a
% given sampling frequency. It plots the unfiltered data first and then 
% filtered data using a low pass butterworth filter of order that you specify
% at half the sample rate (EJM 11-FEB-04)

function mu=FTplot(test, frequency, cutoff, butter)

timelength = length(test);
period = 1/frequency;
stoptime = period *(timelength-1);
time = 0:period:stoptime;

filtdata = zeros(length(test), 7);
for i = 1:6
    filtdata(:,i) = FunctionLowPassFilter(test(:,i), cutoff, period, butter, 0);
end
marker = (test(:,7)-2.5);

%figure(7);
% disp('Original unfiltered data');
% subplot(2,3,1); plot(time, test(:,1)); title('F-x'); ylabel('Force (N)'); xlabel('Time (s)'); axis tight; 
% subplot(2,3,2); plot(time, test(:,2)); title('F-y'); ylabel('Force (N)'); xlabel('Time (s)'); axis tight;
% subplot(2,3,3); plot(time, test(:,3)); title('F-z'); ylabel('Force (N)'); xlabel('Time (s)'); axis tight;
% subplot(2,3,4); plot(time, test(:,4)); title('T-x'); ylabel('Torque (N.m)'); xlabel('Time (s)'); axis tight;
% subplot(2,3,5); plot(time, test(:,5)); title('T-y'); ylabel('Torque (N.m)'); xlabel('Time (s)'); axis tight;
% subplot(2,3,6); plot(time, test(:,6)); title('T-z'); ylabel('Torque (N.m)'); xlabel('Time (s)'); axis tight;
% 
% 
% 
% figure(1);  plot(time, filtdata(:,1)); title('F-x'); ylabel('Force (N)'); xlabel('Time (s)');  hold on;
%             axis([min(time) max(time) min(filtdata(:,1)) max(filtdata(:,1))]);
%             plot(time, marker, 'k:');
% 
% figure(2);  plot(time, filtdata(:,2)); title('F-y'); ylabel('Force (N)'); xlabel('Time (s)'); hold on;
%             axis([min(time) max(time) min(filtdata(:,2)) max(filtdata(:,2))]);
%             plot(time, marker, 'k:');
%             
% figure(3);  plot(time, filtdata(:,3)); title('F-z'); ylabel('Force (N)'); xlabel('Time (s)'); hold on;
%             axis([min(time) max(time) min(filtdata(:,3)) max(filtdata(:,3))]);
%             plot(time, marker, 'k:');
% 
% figure(4);  plot(time, filtdata(:,4)); title('T-x'); ylabel('Torque (N.m)'); xlabel('Time (s)'); hold on;
%             axis([min(time) max(time) min(filtdata(:,4)) max(filtdata(:,4))]);
%             plot(time, marker, 'k:');
% 
% figure(5);  plot(time, filtdata(:,5)); title('T-y'); ylabel('Torque (N.m)'); xlabel('Time (s)'); hold on;
%             axis([min(time) max(time) min(filtdata(:,5)) max(filtdata(:,5))]);
%             plot(time, marker, 'k:');
%             
% figure(6);  plot(time, filtdata(:,6)); title('T-z'); ylabel('Torque (N.m)'); xlabel('Time (s)'); hold on;
%             axis([min(time) max(time) min(filtdata(:,6)) max(filtdata(:,6))]);
%             plot(time, marker, 'k:');
% 
figure(7); subplot(3,1,1); plot(time, filtdata(:,1)); ylabel('F_x (N)'); hold on; title('Force data [N] - Select the slip point to calculate \mu');
            subplot(3,1,3); plot(time, filtdata(:,3)); ylabel('F_z (N)'); hold on; xlabel('Time (s)');
            subplot(3,1,2); plot(time, filtdata(:,2)); ylabel('F_y (N)'); hold on; 
% slipPt=ginput(1); timePt=max(find(time<slipPt(1)));  %Find the nearest time step before the point selected
%             mu=sqrt((filtdata(timePt,1))^2+(filtdata(timePt,2))^2)/abs(filtdata(timePt,3));  % Calculate mu=(sqrt(Fx^2+Fy^2))/Fz
%             fprintf('The calculated friction coef is: %1.4f\n',mu);
getmu


%figure(2);
%disp('Filtered data: Butterworth low pass filtered at half sample rate');
%ubplot(2,3,1); plot(time, filtdata(:,1)); title('F-x'); ylabel('Force (N)'); xlabel('Time (s)'); hold on;
%subplot(2,3,2); plot(time, filtdata(:,2)); title('F-y'); ylabel('Force (N)'); xlabel('Time (s)'); hold on;
%subplot(2,3,3); plot(time, filtdata(:,3)); title('F-z'); ylabel('Force (N)'); xlabel('Time (s)'); hold on;
%subplot(2,3,4); plot(time, filtdata(:,4)); title('T-x'); ylabel('Torque (N.m)'); xlabel('Time (s)'); hold on;
%subplot(2,3,5); plot(time, filtdata(:,5)); title('T-y'); ylabel('Torque (N.m)'); xlabel('Time (s)'); hold on;
%subplot(2,3,6); plot(time, filtdata(:,6)); title('T-z'); ylabel('Torque (N.m)'); xlabel('Time (s)'); hold on;
